@@ -5,7 +5,7 @@ use strict;
 use warnings;
 use v5.10.0;
 
-our $VERSION = '0.011';
+our $VERSION = '0.012';
 
 use Carp;
 use Mastodon::Types qw( Acct Account DateTime Image URI Instance );
@@ -97,7 +97,7 @@ sub authorize {
   }
 
   if ( $self->access_token ) {
-    $log->warn('Client is already authorised');
+    $log->warn('Client is already authorized');
     return $self;
   }
 
@@ -567,15 +567,17 @@ Mastodon::Client - Talk to a Mastodon server
 
 =head1 DESCRIPTION
 
-Mastodon::Client lets you talk to a Mastodon server.
+Mastodon::Client lets you talk to a Mastodon server to obtain authentication
+credentials, read posts from timelines in both static or streaming mode, and
+perform all the other operations exposed by the Mastodon API.
 
-This distribution is still in development, and the interface might
-change in the future. But changes should mostly be to add convenience
-methods for the more common tasks.
+Most of these are available through the convenience methods listed below, which
+validate input parameters and are likely to provide more meaningful feedback in
+case of errors.
 
-The use of the request methods (B<post>, B<get>, etc) is not likely to
-change, and as long as you know the endpoints you are reaching, this
-should be usable right now.
+Alternatively, this distribution can be used via the low-level request methods
+(B<post>, B<get>, etc), which allow direct access to the API endpoints. All
+other methods call one of these at some point.
 
 =head1 ATTRIBUTES
 
@@ -667,7 +669,83 @@ in the default Mastodon web GUI. Defaults to the empty string.
 
 =head1 METHODS
 
-Methods listed here follow the order of those in the official API
+=head2 Authorizing an application
+
+Although not all of the API methods require authentication to be used, most of
+them do. The authentication process involves a) registering an application with
+a Mastodon server to obtain a client secret and ID; b) authorizing the
+application by either providing a user's credentials, or by using an
+authentication URL.
+
+The methods facilitating this process are detailed below:
+
+=over 4
+
+=item B<register()>
+
+=item B<register($data)>
+
+Obtain a client secret and ID from a given mastodon instance. Takes a single
+hash reference as an argument, with the following possible keys:
+
+=over 4
+
+=item B<redirect_uris>
+
+The URL to which authorization codes should be forwarded after authorized by
+the user. Defaults to the value of the B<redirect_uri> attribute.
+
+=item B<scopes>
+
+The scopes requested by this client. Defaults to the value of the B<scopes>
+attribute.
+
+=item B<website>
+
+The client's website. Defaults to the value of the C<website> attribute.
+
+=back
+
+When successful, sets the C<client_secret> and C<client_id> attributes of
+the Mastodon::Client object and returns the modified object.
+
+This should be called B<once> per client and its contents cached locally.
+
+=item B<authorization_url()>
+
+Generate an authorization URL for the given application. Accessing this URL
+via a browser by a logged in user will allow that user to grant this
+application access to the requested scopes. The scopes used are the ones in the
+B<scopes> attribute at the time this method is called.
+
+=item B<authorize()>
+
+=item B<authorize( %data )>
+
+Grant the application access to the requested scopes for a given user. This
+method takes a hash with either an access code or a user's login credentials to
+grant authorization. Valid keys are:
+
+=over 4
+
+=item B<access_code>
+
+The access code obtained by visiting the URL generated by B<authorization_url>.
+
+=item B<username>
+
+=item B<password>
+
+The user's login credentials.
+
+=back
+
+When successful, the method automatically sets the client's B<authorized>
+attribute to a true value and caches the B<access_token> for all future calls.
+
+=back
+
+The remaining methods listed here follow the order of those in the official API
 documentation.
 
 =head2 Accounts
@@ -834,42 +912,6 @@ This method does not require authentication.
 
 =back
 
-=head2 Apps
-
-=over 4
-
-=item B<register()>
-
-=item B<register($data)>
-
-Obtain a client secret and ID from a given mastodon instance. Takes a single
-hash reference as an argument, with the following possible keys:
-
-=over 4
-
-=item B<redirect_uris>
-
-The URL to which authorization codes should be forwarded after authorized by
-the user. Defaults to the value of the B<redirect_uri> attribute.
-
-=item B<scopes>
-
-The scopes requested by this client. Defaults to the value of the B<scopes>
-attribute.
-
-=item B<website>
-
-The client's website. Defaults to the value of the C<website> attribute.
-
-=back
-
-When successful, sets the C<client_secret> and C<client_id> attributes of
-the Mastodon::Client object and returns the modified object.
-
-This should be called B<once> per client and its contents cached locally.
-
-=back
-
 =head2 Blocks
 
 =over 4
@@ -1258,8 +1300,7 @@ the particular tag.
 For more details on how to use this object, see the documentation for
 L<Mastodon::Listener>.
 
-Accessing streaming public timeline will not require authentication (but as
-of this writing still does).
+Accessing streaming public timeline does not require authentication.
 
 =back
 
